@@ -1,11 +1,11 @@
 package API::DirectAdmin::Domain;
 
-use strict;
+use Modern::Perl '2010';
 use Data::Dumper;
 
 use base 'API::DirectAdmin::Component';
 
-our $VERSION = 0.04;
+our $VERSION = 0.05;
 
 # Return domains list
 # INPUT
